function NewArray = MakeStep_NoSensing(ScriptVar, frame_i, OldArray)
    % Make steps for all particles in the no-sensing scenario together
    % Outputs new set of coordinates for all particles in a given frame
    % Output - 
    %    NewArray - m x n array (m=Total num of particles, n = 2 or 3
    %               2 => just coordinates; third column = indices for 
    %               if present in viscous granules (if applicable)
    %
    % Inputs - 
    %    ScriptVar - Parameters container map
    %    OldArray - Element of AllCoordsCell for the old frame
    N_FramesRegion = ScriptVar('N_FramesRegion');
    xyHoneyRatio = ScriptVar('xyHoneyRatio');
    Total_particles = sum(ScriptVar('N_Particles'));
    particle_index = (1:Total_particles)';
    
    %% Get basal step limit (as per the 2x1 StepLim array, StepLim_functional_form
    S_Basal = StepLimBasal(ScriptVar, OldArray(:,1), OldArray(:,2), particle_index);
    
    %% Modify S_Basal depending on if there are explicitly specified viscous zones
    if N_FramesRegion > 0 % If there are explicit viscous zones
        xyHoney = ScriptVar('xyHoney');
        if frame_i <= N_FramesRegion % explicit viscous zones active
            InsideViscousRegion = IsParticleInsideFigure(OldArray(:,1),...
                OldArray(:,2), xyHoney);
            if size(OldArray,2) == 3 % viscous granules
                VG_indices = InsideViscousRegion';
            end
            InsideViscousRegion = xyHoneyRatio*InsideViscousRegion';
            InsideViscousRegion(InsideViscousRegion == 0,:) = 1;
            S_Effective = S_Basal.*InsideViscousRegion;
        else % explicit viscous zones inactive
            S_Effective = S_Basal;
        end
    else
        S_Effective = S_Basal;
    end
    % Sample from uniform distribution [-S_Effective S_Effective]
    r = -S_Effective + 2*S_Effective.*rand(Total_particles,2);
    x_try = OldArray(:,1) + r(:,1);
    y_try = OldArray(:,2) + r(:,2);
    % These coords will be modified after StayWithinBounds is applied
    [xnew, ynew] = StayWithinBounds(ScriptVar, frame_i, x_try, y_try, particle_index);
    if size(OldArray,2) == 3
        NewArray = [xnew, ynew, VG_indices];
        % In case of granules
    else
        NewArray = [xnew, ynew];
    end 
end